@@ -1,3 +1,4 @@
+import sys
 from importlib import import_module
 
 import click
@@ -23,6 +24,7 @@ PLUGINS = [
     "blake2b",
     "blake2s",
 ]
+
 LEGACY_PLUGINS = ["md2", "md4", "ripemd160"]
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
@@ -51,9 +53,17 @@ class Cli(click.MultiCommand):
 
 @click.command(__title__, cls=Cli, context_settings=CONTEXT_SETTINGS)
 @click.version_option(__version__, prog_name=__title__)
-def main():
+def _main():
     """Generate or check various hash values."""
 
 
+def main():
+    # Since Click 8, glob patterns, user home directory and environment variables will
+    # be expanded automatically on Windows, which causes unexpected behaviour. What's
+    # more, there is no way to disable expansion through quotation marks on Windows
+    # command line. So we suppress this feature by passing arguments explicitly.
+    return _main(sys.argv[1:])
+
+
 if __name__ == "__main__":
     main()
