@@ -8,12 +8,12 @@ from click_option_group import MutuallyExclusiveOptionGroup
 from . import __version__
 from .core import (
     CheckHashLineError,
-    Hasher,
     HashFileReader,
     HashFileWriter,
     check_hash_line,
     generate_hash_line,
 )
+from .hasher import Hasher
 from .utils.glob import glob_filters
 
 
@@ -90,7 +90,7 @@ class Output(object):
         pass
 
 
-class GetHash(object):
+class Gethash(object):
     """Provide uniform interface for CLI scripts."""
 
     def __init__(self, ctx, **kwargs):
@@ -99,7 +99,6 @@ class GetHash(object):
 
         self.glob_mode = kwargs.pop("glob", 1)
         self.glob_type = kwargs.pop("type", "a")
-        self.recursive = kwargs.pop("recursive", False)
         self.sync = kwargs.pop("sync", False)
 
         self.stdout = kwargs.pop("stdout", sys.stdout)
@@ -121,9 +120,9 @@ class GetHash(object):
         self.dir_ok = kwargs.pop("dir", False)
         tqdm_args = {
             "file": self.stderr,
-            "ascii": kwargs.pop("tqdm-ascii", False),
-            "disable": kwargs.pop("tqdm-disable", False),
-            "leave": kwargs.pop("tqdm-leave", False),
+            "ascii": kwargs.pop("tqdm_ascii", False),
+            "disable": kwargs.pop("tqdm_disable", False),
+            "leave": kwargs.pop("tqdm_leave", False),
         }
         self.hasher = Hasher(ctx, tqdm_args=tqdm_args)
 
@@ -145,7 +144,9 @@ class GetHash(object):
             pathnames,
             mode=self.glob_mode,
             type=self.glob_type,
-            recursive=self.recursive,
+            recursive=True,
+            user=True,
+            vars=True,
         )
 
     def hash_function(self, path):
@@ -214,20 +215,16 @@ def script_main(ctx, files, **options):
     stderr = open(os.devnull, "w") if no_stderr else sys.stderr
 
     check = options.pop("check", False)
-    with GetHash(ctx, stdout=stdout, stderr=stderr, **options) as gh:
-        gh(check, files)
+    with Gethash(ctx, stdout=stdout, stderr=stderr, **options) as gethash:
+        gethash(check, files)
 
 
-def gethashcli(cmdname, hashname, suffix):
+def gethashcli(cmdname, hashname, suffix, **ignored):
     """Apply click decorators to the main function."""
 
     def decorator(func):
-        path_format = MutuallyExclusiveOptionGroup(
-            "Path Format", help="Set the path format in checksum files."
-        )
-        output_mode = MutuallyExclusiveOptionGroup(
-            "Output Mode", help="Set the file output mode."
-        )
+        path_format = MutuallyExclusiveOptionGroup("Path Format")
+        output_mode = MutuallyExclusiveOptionGroup("Output Mode")
 
         @click.command(
             cmdname,
@@ -274,14 +271,6 @@ def gethashcli(cmdname, hashname, suffix):
             help="Set file type. If ``a``, include all types; if ``d``, include "
             "directories; if ``f``, include files.",
         )
-        @click.option(
-            "-r",
-            "--recursive",
-            is_flag=True,
-            help="Enable recursive matching, i.e. "
-            "the pattern ``**`` will match any files and zero or more "
-            "directories, subdirectories and symbolic links to directories.",
-        )
         @click.option(
             "-y",
             "--sync",
